@@ -525,13 +525,29 @@ function UIMenu:appendMenu(text, menu)
   }
 end
 
+-- A function to set the menu hotkey strings, whether a string or table.
+-- Usage: hotkey_value_label(hotkey name as string)
+-- Ex: hotkey_value_label("ingame_loadMenu") will produce (SHIFT+L) by default.
+--!param hotkey_name (string) Name of hotkey to be converted to string.
+--!param hotkeys (table) The app's hotkey table. I.E. app.hotkeys
+--!return (string) The hotkey returned in this format: (KEY+KEY)
+local function hotkey_value_label(hotkey_name, hotkeys)
+  local hotkey_value = hotkeys[hotkey_name]
+  if hotkey_value == nil then
+    return ""
+  end
+  return string.upper(array_join(hotkey_value, "+"))
+end
+
 --! Make a menu for the map editor.
 --!param app Application.
 function UIMenuBar:makeMapeditorMenu(app)
   local menu = UIMenu()
-  menu:appendItem(_S.menu_file.load, function() self.ui:addWindow(UILoadMap(self.ui, "map")) end)
-    :appendItem(_S.menu_file.save, function() self.ui:addWindow(UISaveMap(self.ui)) end)
-    :appendItem(_S.menu_file.quit, function() self.ui:quit() end)
+  local hotkeys = app.hotkeys
+
+  menu:appendItem(_S.menu_file.load:format(hotkey_value_label("ingame_loadMenu", hotkeys)), function() self.ui:addWindow(UILoadMap(self.ui, "map")) end)
+    :appendItem(_S.menu_file.save:format(hotkey_value_label("ingame_saveMenu", hotkeys)), function() self.ui:addWindow(UISaveMap(self.ui)) end)
+    :appendItem(_S.menu_file.quit:format(hotkey_value_label("ingame_quitLevel", hotkeys)), function() self.ui:quit() end)
   self:addMenu(_S.menu.file, menu)
 
   menu = UIMenu()
@@ -546,10 +562,12 @@ end
 --!param app Application.
 function UIMenuBar:makeGameMenu(app)
   local menu = UIMenu()
-  menu:appendItem(_S.menu_file.load, function() self.ui:addWindow(UILoadGame(self.ui, "game")) end)
-    :appendItem(_S.menu_file.save, function() self.ui:addWindow(UISaveGame(self.ui)) end)
-    :appendItem(_S.menu_file.restart, function() app:restart() end)
-    :appendItem(_S.menu_file.quit, function() self.ui:quit() end)
+  local hotkeys = app.hotkeys
+
+  menu:appendItem(_S.menu_file.load:format(hotkey_value_label("ingame_loadMenu", hotkeys)), function() self.ui:addWindow(UILoadGame(self.ui, "game")) end)
+    :appendItem(_S.menu_file.save:format(hotkey_value_label("ingame_saveMenu", hotkeys)), function() self.ui:addWindow(UISaveGame(self.ui)) end)
+    :appendItem(_S.menu_file.restart:format(hotkey_value_label("ingame_restartLevel", hotkeys)), function() app:restart() end)
+    :appendItem(_S.menu_file.quit:format(hotkey_value_label("ingame_quitLevel", hotkeys)), function() self.ui:quit() end)
   self:addMenu(_S.menu.file, menu)
 
   local options = UIMenu()
@@ -587,7 +605,7 @@ function UIMenuBar:makeGameMenu(app)
       return volume_menu
     end
 
-  options:appendCheckItem(_S.menu_options.sound,
+  options:appendCheckItem(_S.menu_options.sound:format(hotkey_value_label("ingame_toggleSounds", hotkeys)),
     app.config.play_sounds,
     function(item)
       app.audio:playSoundEffects(item.checked)
@@ -599,7 +617,7 @@ function UIMenuBar:makeGameMenu(app)
     end)
 
 
-  options:appendCheckItem(_S.menu_options.announcements,
+  options:appendCheckItem(_S.menu_options.announcements:format(hotkey_value_label("ingame_toggleAnnouncements", hotkeys)),
     app.config.play_announcements,
     function(item)
       app.config.play_announcements = item.checked
@@ -610,7 +628,7 @@ function UIMenuBar:makeGameMenu(app)
       return app.config.play_announcements
     end)
 
- options:appendCheckItem(_S.menu_options.music,
+ options:appendCheckItem(_S.menu_options.music:format(hotkey_value_label("ingame_toggleMusic", hotkeys)),
     app.config.play_music,
     function(item)
       app.config.play_music = item.checked
@@ -626,7 +644,7 @@ function UIMenuBar:makeGameMenu(app)
     :appendMenu(_S.menu_options.sound_vol,         appendVolume("sound"))
     :appendMenu(_S.menu_options.announcements_vol, appendVolume("announcement"))
     :appendMenu(_S.menu_options.music_vol,         appendVolume("music"))
-    :appendItem(_S.menu_options.jukebox, function() self.ui:addWindow(UIJukebox(app)) end)
+    :appendItem(_S.menu_options.jukebox:format(hotkey_value_label("ingame_jukebox", hotkeys)), function() self.ui:addWindow(UIJukebox(app)) end)
   end
 
   local function boolean_runtime_config(option)
@@ -651,7 +669,7 @@ function UIMenuBar:makeGameMenu(app)
       app:setCaptureMouse()
     end)
 
-  options:appendCheckItem(_S.menu_options.adviser_disabled,
+  options:appendCheckItem(_S.menu_options.adviser_disabled:format(hotkey_value_label("ingame_toggleAdvisor", hotkeys)),
     not app.config.adviser_disabled,
     function(item)
       app.config.adviser_disabled = not item.checked
@@ -708,26 +726,29 @@ function UIMenuBar:makeGameMenu(app)
   end
 
   options:appendMenu(_S.menu_options.game_speed, UIMenu()
-    :appendCheckItem(_S.menu_options_game_speed.pause,              rate("Pause"))
-    :appendCheckItem(_S.menu_options_game_speed.slowest,            rate("Slowest"))
-    :appendCheckItem(_S.menu_options_game_speed.slower,             rate("Slower"))
-    :appendCheckItem(_S.menu_options_game_speed.normal,             rate("Normal")) -- (default)
-    :appendCheckItem(_S.menu_options_game_speed.max_speed,          rate("Max speed"))
-    :appendCheckItem(_S.menu_options_game_speed.and_then_some_more, rate("And then some more"))
+    :appendCheckItem(_S.menu_options_game_speed.pause:format(hotkey_value_label("ingame_pause", hotkeys)),                          rate("Pause"))
+    :appendCheckItem(_S.menu_options_game_speed.slowest:format(hotkey_value_label("ingame_gamespeed_slowest", hotkeys)),             rate("Slowest"))
+    :appendCheckItem(_S.menu_options_game_speed.slower:format(hotkey_value_label("ingame_gamespeed_slower", hotkeys)),               rate("Slower"))
+    :appendCheckItem(_S.menu_options_game_speed.normal:format(hotkey_value_label("ingame_gamespeed_normal", hotkeys)),               rate("Normal")) -- (default)
+    :appendCheckItem(_S.menu_options_game_speed.max_speed:format(hotkey_value_label("ingame_gamespeed_max", hotkeys)),               rate("Max speed"))
+    :appendCheckItem(_S.menu_options_game_speed.and_then_some_more:format(hotkey_value_label("ingame_gamespeed_thensome", hotkeys)), rate("And then some more"))
   )
+
   self:addMenu(_S.menu.options, options)
+
   self:addMenu(_S.menu.charts, UIMenu()
-    :appendItem(_S.menu_charts.bank_manager, function() self.ui.bottom_panel:dialogBankManager(true) end)
-    :appendItem(_S.menu_charts.statement, function() self.ui.bottom_panel:dialogBankStats(true) end)
-    :appendItem(_S.menu_charts.staff_listing, function() self.ui.bottom_panel:dialogStaffManagement(true) end)
-    :appendItem(_S.menu_charts.town_map, function() self.ui.bottom_panel:dialogTownMap(true) end)
-    :appendItem(_S.menu_charts.casebook, function() self.ui.bottom_panel:dialogDrugCasebook(true) end)
-    :appendItem(_S.menu_charts.research, function() self.ui.bottom_panel:dialogResearch(true) end)
-    :appendItem(_S.menu_charts.status, function() self.ui.bottom_panel:dialogStatus(true) end)
-    :appendItem(_S.menu_charts.graphs, function() self.ui.bottom_panel:dialogCharts(true) end)
-    :appendItem(_S.menu_charts.policy, function() self.ui.bottom_panel:dialogPolicy(true) end)
+    :appendItem(_S.menu_charts.bank_manager:format(hotkey_value_label("ingame_panel_bankManager", hotkeys)), function() self.ui.bottom_panel:dialogBankManager(true) end)
+    :appendItem(_S.menu_charts.statement:format(hotkey_value_label("ingame_panel_bankStats", hotkeys)), function() self.ui.bottom_panel:dialogBankStats(true) end)
+    :appendItem(_S.menu_charts.staff_listing:format(hotkey_value_label("ingame_panel_staffManage", hotkeys)), function() self.ui.bottom_panel:dialogStaffManagement(true) end)
+    :appendItem(_S.menu_charts.town_map:format(hotkey_value_label("ingame_panel_townMap", hotkeys)), function() self.ui.bottom_panel:dialogTownMap(true) end)
+    :appendItem(_S.menu_charts.casebook:format(hotkey_value_label("ingame_panel_casebook", hotkeys)), function() self.ui.bottom_panel:dialogDrugCasebook(true) end)
+    :appendItem(_S.menu_charts.research:format(hotkey_value_label("ingame_panel_research", hotkeys)), function() self.ui.bottom_panel:dialogResearch(true) end)
+    :appendItem(_S.menu_charts.status:format(hotkey_value_label("ingame_panel_status", hotkeys)), function() self.ui.bottom_panel:dialogStatus(true) end)
+    :appendItem(_S.menu_charts.graphs:format(hotkey_value_label("ingame_panel_charts", hotkeys)), function() self.ui.bottom_panel:dialogCharts(true) end)
+    :appendItem(_S.menu_charts.policy:format(hotkey_value_label("ingame_panel_policy", hotkeys)), function() self.ui.bottom_panel:dialogPolicy(true) end)
     :appendItem(_S.menu_charts.briefing, function() self.ui:showBriefing() end)
   )
+
   local function _(s) return "  " .. s:upper() .. "  " end
   local function limit_camera(item)
     app.ui:limitCamera(item.checked)
@@ -759,17 +780,17 @@ function UIMenuBar:makeGameMenu(app)
   if self.ui.app.config.debug then
     self:addMenu(_S.menu.debug, UIMenu() -- Debug
       :appendMenu(_S.menu_debug.jump_to_level, levels_menu)
-      :appendItem(_S.menu_debug.connect_debugger, function() self.ui:connectDebugger() end)
+      :appendItem(_S.menu_debug.connect_debugger:format(hotkey_value_label("global_connectDebugger", hotkeys)), function() self.ui:connectDebugger() end)
       :appendCheckItem(_S.menu_debug.limit_camera,         true, limit_camera, nil, function() return self.ui.limit_to_visible_diamond end)
       :appendCheckItem(_S.menu_debug.disable_salary_raise, false, disable_salary_raise, nil, function() return self.ui.app.world.debug_disable_salary_raise end)
       :appendItem(_S.menu_debug.make_debug_fax,     function() self.ui:makeDebugFax() end)
       :appendItem(_S.menu_debug.make_debug_patient, function() self.ui:addWindow(UIMakeDebugPatient(self.ui)) end)
-      :appendItem(_S.menu_debug.cheats,             function() self.ui:addWindow(UICheats(self.ui)) end)
-      :appendItem(_S.menu_debug.lua_console,        function() self.ui:addWindow(UILuaConsole(self.ui)) end)
-      :appendItem(_S.menu_debug.debug_script,       function() self.ui:runDebugScript() end)
+      :appendItem(_S.menu_debug.cheats:format(hotkey_value_label("ingame_showCheatWindow", hotkeys)),             function() self.ui:addWindow(UICheats(self.ui)) end)
+      :appendItem(_S.menu_debug.lua_console:format(hotkey_value_label("global_showLuaConsole", hotkeys)),        function() self.ui:addWindow(UILuaConsole(self.ui)) end)
+      :appendItem(_S.menu_debug.debug_script:format(hotkey_value_label("global_runDebugScript", hotkeys)),       function() self.ui:runDebugScript() end)
       :appendItem(_S.menu_debug.calls_dispatcher,   function() self.ui:addWindow(UICallsDispatcher(self.ui)) end)
-      :appendItem(_S.menu_debug.dump_strings,       function() self.ui.app:dumpStrings() end)
-      :appendItem(_S.menu_debug.dump_gamelog,       function() self.ui.app.world:dumpGameLog() end)
+      :appendItem(_S.menu_debug.dump_strings:format(hotkey_value_label("ingame_poopStrings", hotkeys)),       function() self.ui.app:dumpStrings() end)
+      :appendItem(_S.menu_debug.dump_gamelog:format(hotkey_value_label("ingame_poopLog", hotkeys)),       function() self.ui.app.world:dumpGameLog() end)
       :appendMenu(_S.menu_debug.map_overlay,        UIMenu()
         :appendCheckItem(_S.menu_debug_overlay.none,         true, overlay(), "")
         :appendCheckItem(_S.menu_debug_overlay.flags,       false, overlay("flags"), "")
