@@ -67,7 +67,6 @@ function UIPlaceObjects:UIPlaceObjects(ui, object_list, pay_for)
   end
   self:addPanel(114,   0, 90) -- Dialog mid-piece
   self:addPanel(115,   0, 100):makeButton(9, 8, 41, 42, 116, self.cancel):setSound("no4.wav"):setTooltip(_S.tooltip.place_objects_window.cancel)
-  self:addKeyHandler("escape", self.cancel)
   self.purchase_button =
   self:addPanel(117,  50, 100):makeButton(1, 8, 41, 42, 118, self.purchaseItems):setTooltip(_S.tooltip.place_objects_window.buy_sell)
     :setDisabledSprite(127):enable(false) -- Disabled purchase items button
@@ -86,9 +85,14 @@ function UIPlaceObjects:UIPlaceObjects(ui, object_list, pay_for)
   self.num_slots = 0
 
   self:addObjects(object_list, pay_for)
-  self:addKeyHandler("space", self.tryNextOrientation)
-
   ui:setWorldHitTest(false)
+  UIPlaceObjects.registerKeyHandlers(self)
+end
+
+function UIPlaceObjects:registerKeyHandlers()
+  self:addKeyHandler("global_cancel", self.cancel)
+  self:addKeyHandler("global_cancel_alt", self.cancel)
+  self:addKeyHandler("ingame_rotateobject", self.tryNextOrientation)
 end
 
 -- changes the window size and buttons to num_slots slots
@@ -505,6 +509,9 @@ function UIPlaceObjects:placeObject(dont_close_if_empty)
     if real_obj.strength then
       real_obj:calculateSmoke(room)
     end
+    if class.is(real_obj, Machine) then
+      real_obj:setHandymanRepairPosition(self.object_orientation)
+    end
   else
     local object_footprint = object.object.orientations[self.object_orientation].footprint
     self.world:prepareFootprintTilesForBuild(object_footprint, self.object_cell_x, self.object_cell_y)
@@ -512,6 +519,7 @@ function UIPlaceObjects:placeObject(dont_close_if_empty)
         self.object_cell_x, self.object_cell_y, self.object_orientation)
     real_obj:setState(object.state)
   end
+
   if room then
     room.objects[real_obj] = true
   end
@@ -819,3 +827,8 @@ function UIPlaceObjects:selectObjectType(object_type)
     end
   end
 end
+
+function UIPlaceObjects:afterLoad(old, new)
+  Window.afterLoad(self, old, new)
+  UIPlaceObjects.registerKeyHandlers(self)
+end
