@@ -300,28 +300,29 @@ function Humanoid:Humanoid(...)
 
   self.build_callbacks  = {--[[set]]}
   self.remove_callbacks = {--[[set]]}
+  self.staff_change_callbacks = {--[[set]]}
 end
 
 -- Save game compatibility
 function Humanoid:afterLoad(old, new)
-  if old < 38 then
+  if old < 38 and new >= 38 then
     -- should existing patients be updated and be getting really ill?
     -- adds the new variables for health icons
     self.attributes["health"] = math.random(60, 100) /100
   end
   -- make sure female slack patients have the correct animation
-  if old < 42 then
+  if old < 42 and new >= 42 then
     if self.humanoid_class == "Slack Female Patient" then
       self.die_anims = die_animations["Slack Female Patient"]
     end
   end
-  if old < 77 then
+  if old < 77 and new >= 77 then
     self.has_vomitted = 0
   end
-  if old < 49 then
+  if old < 49 and new >= 49 then
     self.has_fallen = 1
   end
-  if old < 61 then
+  if old < 61 and new >= 61 then
     -- callbacks changed
     self.build_callbacks = {}
     self.remove_callbacks = {}
@@ -334,14 +335,18 @@ function Humanoid:afterLoad(old, new)
       self.toilet_callback = nil
     end
   end
-  if old < 83 and self.humanoid_class == "Chewbacca Patient" then
+  if old < 83 and new >= 83 and self.humanoid_class == "Chewbacca Patient" then
     self.die_anims.extra_east = 1682
   end
+  if old < 134 and new >= 134 then
+    self.staff_change_callbacks = {}
+  end
 
   for _, action in pairs(self.action_queue) do
     -- Sometimes actions not actual instances of HumanoidAction
     HumanoidAction.afterLoad(action, old, new)
   end
+
   Entity.afterLoad(self, old, new)
 end
 
@@ -819,6 +824,12 @@ function Humanoid:notifyNewRoom(room)
   end
 end
 
+function Humanoid:notifyOfStaffChange(staff)
+  for callback, _ in pairs(self.staff_change_callbacks) do
+    callback(staff)
+  end
+end
+
 -- Registers a new remove callback for this humanoid.
 --!param callback (function) The callback to call when a room has been removed.
 function Humanoid:registerRoomRemoveCallback(callback)
@@ -841,6 +852,29 @@ function Humanoid:unregisterRoomRemoveCallback(callback)
   end
 end
 
+
+-- Registers a new staff change callback for this humanoid.
+--!param callback (function) The callback to call when a staff member has been hired or fired
+function Humanoid:registerStaffChangeCallback(callback)
+  if self.staff_change_callbacks and not self.staff_change_callbacks[callback] then
+    self.staff_change_callbacks[callback] = true
+  else
+    self.world:gameLog("Warning: Trying to re-add staff callback (" .. tostring(callback) .. ") for humanoid (" .. tostring(self) .. ").")
+  end
+end
+
+-- Unregisters a staff change callback for this humanoid.
+--!param callback (function) The callback to remove.
+function Humanoid:unregisterStaffChangeCallback(callback)
+
+  if self.staff_change_callbacks and self.staff_change_callbacks[callback] then
+    self.staff_change_callbacks[callback] = nil
+  else
+    self.world:gameLog("Warning: Trying to remove nonexistant staff callback (" .. tostring(callback) .. ") from humanoid (" .. tostring(self) .. ").")
+  end
+end
+
+
 -- Function called when a humanoid is sent away from the hospital to prevent
 -- further actions taken as a result of a callback
 function Humanoid:unregisterCallbacks()
@@ -852,6 +886,10 @@ function Humanoid:unregisterCallbacks()
   for cb, _ in pairs(self.remove_callbacks) do
     self:unregisterRoomRemoveCallback(cb)
   end
+  -- Remove callbacks for removed rooms
+  for cb, _ in pairs(self.staff_change_callbacks) do
+    self:unregisterStaffChangeCallback(cb)
+  end
   -- Remove any message related to the humanoid.
   if self.message_callback then
     self:message_callback(true)
