@@ -18,7 +18,8 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE. --]]
 
-dofile "ui"
+corsixth.require("ui")
+corsixth.require("announcer")
 
 --! Variant of UI for running games
 class "GameUI" (UI)
@@ -26,7 +27,9 @@ class "GameUI" (UI)
 ---@type GameUI
 local GameUI = _G["GameUI"]
 
-local TH = require "TH"
+local TH = require("TH")
+
+local Announcer = _G["Announcer"]
 
 -- The maximum distance to shake the screen from the origin during an
 -- earthquake with full intensity.
@@ -44,6 +47,7 @@ local multigesture_pinch_amplification_factor = 100
 --!param map_editor (bool) Whether the map is editable.
 function GameUI:GameUI(app, local_hospital, map_editor)
   self:UI(app)
+  self.app = app
 
   self.hospital = local_hospital
   self.tutorial = { chapter = 0, phase = 0 }
@@ -79,37 +83,88 @@ function GameUI:GameUI(app, local_hospital, map_editor)
   self.transparent_walls = false
   self.do_world_hit_test = true
 
-  self:setRandomAnnouncementTarget()
-  self.ticks_since_last_announcement = 0
-
   self.momentum = app.config.scrolling_momentum
   self.current_momentum = {x = 0.0, y = 0.0, z = 0.0}
   self.multigesturemove = {x = 0.0, y = 0.0}
 
+  self.recallpositions = {}
+
   self.speed_up_key_pressed = false
 
   -- The currently specified intensity value for earthquakes. To abstract
   -- the effect from the implementation this value is a number between 0
   -- and 1.
   self.shake_screen_intensity = 0
+
+  self.announcer = Announcer(app)
 end
 
 function GameUI:setupGlobalKeyHandlers()
   UI.setupGlobalKeyHandlers(self)
 
-  self:addKeyHandler("escape", self, self.setEditRoom, false)
-  self:addKeyHandler("escape", self, self.showMenuBar)
-  self:addKeyHandler("z", self, self.keySpeedUp)
-  self:addKeyHandler("x", self, self.keyTransparent)
-  self:addKeyHandler({"shift", "a"}, self, self.toggleAdviser)
-  self:addKeyHandler({"ctrl", "d"}, self.app.world, self.app.world.dumpGameLog)
-  self:addKeyHandler({"ctrl", "t"}, self.app, self.app.dumpStrings)
-  self:addKeyHandler({"alt", "a"}, self, self.togglePlayAnnouncements)
-  self:addKeyHandler({"alt", "s"}, self, self.togglePlaySounds)
-  self:addKeyHandler({"alt", "m"}, self, self.togglePlayMusic)
+  -- Set the scrolling keys.
+  self.scroll_keys = {
+     [tostring(self.app.hotkeys["ingame_scroll_up"])] = {x = 0, y = -10},
+     [tostring(self.app.hotkeys["ingame_scroll_down"])] = {x = 0, y = 10},
+     [tostring(self.app.hotkeys["ingame_scroll_left"])] = {x = -10, y = 0},
+     [tostring(self.app.hotkeys["ingame_scroll_right"])]	= {x = 10, y = 0},
+  }
+
+  -- This is the long version of the shift speed key.
+  -- i.e. if the "ingame_scroll_shift" key is "ctrl", then it will give us
+  --  "left ctrl" and "right ctrl" for reference against the rawchar in
+  --  "onKeyDown()" and "onKeyUp()"
+  self.shift_scroll_key_long = {}
+  self.shift_scroll_speed_pressed = false
+  local temp_table = {}
+  local shift_scroll_key_index = 1
+  if type(self.app.hotkeys["ingame_scroll_shift"]) == "string" then
+    temp_table = {self.app.hotkeys["ingame_scroll_shift"]}
+  elseif type(self.app.hotkeys["ingame_scroll_shift"]) == "table" then
+    temp_table = shallow_clone(self.app.hotkeys["ingame_scroll_shift"])
+  end
+  -- Go through the "ingame_scroll_shift" key table and see if it has any modifier names.
+  for _, v in pairs (temp_table) do
+    -- If it does then add long name version of them into the long key table.
+    if v == "ctrl" then
+      self.shift_scroll_key_long[shift_scroll_key_index] = "left ctrl"
+      shift_scroll_key_index = shift_scroll_key_index + 1
+      self.shift_scroll_key_long[shift_scroll_key_index] = "right ctrl"
+      shift_scroll_key_index = shift_scroll_key_index + 1
+    elseif v == "alt" then
+      self.shift_scroll_key_long[shift_scroll_key_index] = "left alt"
+      shift_scroll_key_index = shift_scroll_key_index + 1
+      self.shift_scroll_key_long[shift_scroll_key_index] = "right alt"
+      shift_scroll_key_index = shift_scroll_key_index + 1
+    elseif v == "shift" then
+      self.shift_scroll_key_long[shift_scroll_key_index] = "left shift"
+      shift_scroll_key_index = shift_scroll_key_index + 1
+      self.shift_scroll_key_long[shift_scroll_key_index] = "right shift"
+      shift_scroll_key_index = shift_scroll_key_index + 1
+    end
+  end
+
+  self:addKeyHandler("global_window_close", self, self.setEditRoom, false)
+  self:addKeyHandler("ingame_showmenubar", self, self.showMenuBar)
+  self:addKeyHandler("ingame_gamespeed_speedup", self, self.keySpeedUp)
+  self:addKeyHandler("ingame_setTransparent", self, self.keyTransparent)
+  self:addKeyHandler("ingame_toggleAdvisor", self, self.toggleAdviser)
+  self:addKeyHandler("ingame_poopLog", self.app.world, self.app.world.dumpGameLog)
+  self:addKeyHandler("ingame_poopStrings", self.app, self.app.dumpStrings)
+  self:addKeyHandler("ingame_toggleAnnouncements", self, self.togglePlayAnnouncements)
+  self:addKeyHandler("ingame_toggleSounds", self, self.togglePlaySounds)
+  self:addKeyHandler("ingame_toggleMusic", self, self.togglePlayMusic)
+
+  -- scroll to map position
+  for i = 0, 9 do
+    -- set camera view
+    self:addKeyHandler(string.format("ingame_storePosition_%d", i), self, self.setMapRecallPosition, i)
+    -- recall camera view
+    self:addKeyHandler(string.format("ingame_recallPosition_%d", i), self, self.recallMapPosition, i)
+  end
 
   if self.app.config.debug then
-    self:addKeyHandler("f11", self, self.showCheatsWindow)
+    self:addKeyHandler("ingame_showCheatWindow", self, self.showCheatsWindow)
   end
 end
 
@@ -248,26 +303,22 @@ function GameUI:resync(ui)
   self.key_to_button_remaps = ui.key_to_button_remaps
 end
 
-local scroll_keys = {
-  up    = {x =   0, y = -10},
-  right = {x =  10, y =   0},
-  down  = {x =   0, y =  10},
-  left  = {x = -10, y =   0},
-  ["keypad 8"] = {x =   0, y = -10},
-  ["keypad 6"] = {x =  10, y =   0},
-  ["keypad 2"] = {x =   0, y =  10},
-  ["keypad 4"] = {x = -10, y =   0},
-}
-
 function GameUI:updateKeyScroll()
   local dx, dy = 0, 0
-  for key, scr in pairs(scroll_keys) do
+  for key, scr in pairs(self.scroll_keys) do
     if self.buttons_down[key] then
       dx = dx + scr.x
       dy = dy + scr.y
     end
   end
+  --If there is any movement on the x or y axis...
   if dx ~= 0 or dy ~= 0 then
+    --Get the length of the scrolling vector.
+    local mag = (dx^2 + dy^2) ^ 0.5
+    --Then normalize the scrolling vector, after which multiply it by the scroll speed variable used in self.scroll_keys, which is 10 as of 14/10/18.
+    dx = (dx / mag) * 10
+    dy = (dy / mag) * 10
+    -- Set the scroll amount to be used.
     self.tick_scroll_amount = {x = dx, y = dy}
     return true
   else
@@ -291,7 +342,13 @@ function GameUI:onKeyDown(rawchar, modifiers, is_repeat)
     return true
   end
   local key = rawchar:lower()
-  if scroll_keys[key] then
+  -- If key is shift speed key...
+  for _, v in pairs(self.shift_scroll_key_long) do
+    if v == key then
+      self.shift_scroll_speed_pressed = true
+    end
+  end
+  if self.scroll_keys[key] then
     self:updateKeyScroll()
     return
   end
@@ -303,7 +360,12 @@ function GameUI:onKeyUp(rawchar)
   end
 
   local key = rawchar:lower()
-  if scroll_keys[key] then
+  for _, v in pairs(self.shift_scroll_key_long) do
+    if v == key then
+      self.shift_scroll_speed_pressed = false
+    end
+  end
+  if self.scroll_keys[key] then
     self:updateKeyScroll()
     return
   end
@@ -357,7 +419,8 @@ function GameUI:onCursorWorldPositionChange()
   local x = math.floor(self.screen_offset_x + self.cursor_x / zoom)
   local y = math.floor(self.screen_offset_y + self.cursor_y / zoom)
   local entity = nil
-  if self.do_world_hit_test and not self:hitTest(self.cursor_x, self.cursor_y) then
+  local overwindow = self:hitTest(self.cursor_x, self.cursor_y)
+  if self.do_world_hit_test and not overwindow then
     entity = self.app.map.th:hitTestObjects(x, y)
     if self.do_world_hit_test ~= true then
       -- limit to non-door objects in room
@@ -410,7 +473,7 @@ function GameUI:onCursorWorldPositionChange()
   wx = math.floor(wx)
   wy = math.floor(wy)
   local room
-  if wx > 0 and wy > 0 and wx < self.app.map.width and wy < self.app.map.height then
+  if not overwindow and wx > 0 and wy > 0 and wx < self.app.map.width and wy < self.app.map.height then
     room = self.app.world:getRoom(wx, wy)
   end
   if room ~= self.cursor_room then
@@ -465,6 +528,10 @@ end
 
 -- TODO: try to remove duplication with UI:onMouseMove
 function GameUI:onMouseMove(x, y, dx, dy)
+  if self.mouse_released then
+    return false
+  end
+
   local repaint = UpdateCursorPosition(self.app.video, x, y)
   if self.app.moviePlayer.playing then
     return false
@@ -665,16 +732,8 @@ function GameUI:onMouseWheel(x, y)
   return UI.onMouseWheel(self, x, y)
 end
 
-function GameUI:setRandomAnnouncementTarget()
-  -- NB: Every tick is 30ms, so 2000 ticks is 1 minute
-  self.random_announcement_ticks_target = math.random(8000, 12000)
-end
-
-function GameUI:playAnnouncement(name, played_callback, played_callback_delay)
-  self.ticks_since_last_announcement = 0
-  if self.app.world:getLocalPlayerHospital():hasStaffedDesk() then
-    UI.playAnnouncement(self, name, played_callback, played_callback_delay)
-  end
+function GameUI:playAnnouncement(name, priority, played_callback, played_callback_delay)
+  self.announcer:playAnnouncement(name, priority, played_callback, played_callback_delay)
 end
 
 function GameUI:onTick()
@@ -698,15 +757,6 @@ function GameUI:onTick()
     self.multigesturemove.x = 0.0
     self.multigesturemove.y = 0.0
   end
-  if not self.app.world:isCurrentSpeed("Pause") then
-    local ticks_since_last_announcement = self.ticks_since_last_announcement
-    if ticks_since_last_announcement >= self.random_announcement_ticks_target then
-      self:playAnnouncement("rand*.wav")
-      self:setRandomAnnouncementTarget()
-    else
-      self.ticks_since_last_announcement = ticks_since_last_announcement + 1
-    end
-  end
   if self.tick_scroll_amount or self.tick_scroll_amount_mouse then
     -- The scroll amount per tick gradually increases as the duration of the
     -- scroll increases due to this multiplier.
@@ -741,7 +791,7 @@ function GameUI:onTick()
     -- By multiplying by 0.5, we allow for setting slower than normal
     -- scroll speeds, and ensure there is no behaviour change for players
     -- who do not modify their config file.
-    if self.app.key_modifiers.shift then
+    if self.shift_scroll_speed_pressed then
       mult = mult * self.app.config.shift_scroll_speed * 0.5
     else
       mult = mult * self.app.config.scroll_speed * 0.5
@@ -755,6 +805,9 @@ function GameUI:onTick()
   if self:onCursorWorldPositionChange() then
     repaint = true
   end
+
+  self.announcer:onTick()
+
   return repaint
 end
 
@@ -1078,6 +1131,24 @@ function GameUI:startTutorial(chapter)
   self:tutorialStep(chapter, 0, 1)
 end
 
+--! Converts centre of screen co-ordinates to world tile positions and stores the values for later recall
+-- param index (integer) Postion in recallpositions table
+function GameUI:setMapRecallPosition(index)
+  local cx, cy = self:ScreenToWorld(self.app.config.width / 2, self.app.config.height / 2)
+  self.recallpositions[index] = {x = cx, y = cy, z = self.zoom_factor}
+end
+
+--! Retrives stored recall position and attempts to scroll to that position - will be limited to the bounds of the camera when zoomed out
+-- param index (integer) Postion in recallpositions table
+function GameUI:recallMapPosition(index)
+  if self.recallpositions[index] ~= nil then
+    local sx, sy = self.app.map:WorldToScreen(self.recallpositions[index].x,  self.recallpositions[index].y)
+    local dx, dy = self.app.map:ScreenToWorld(self.app.config.width / 2, self.app.config.height / 2)
+    self:setZoom(self.recallpositions[index].z)
+    self:scrollMapTo(sx + dx, sy + dy)
+  end
+end
+
 function GameUI:setEditRoom(enabled)
   -- TODO: Make the room the cursor is over flash
   if enabled then
@@ -1112,10 +1183,6 @@ function GameUI:afterLoad(old, new)
   if old < 23 then
     self.do_world_hit_test = not self:getWindow(UIPlaceObjects)
   end
-  if old < 28 then
-    self:setRandomAnnouncementTarget()
-    self.ticks_since_last_announcement = 0
-  end
   if old < 34 then
     self.adviser.queued_messages = {}
     self.adviser.phase = 0
@@ -1123,9 +1190,6 @@ function GameUI:afterLoad(old, new)
     self.adviser.frame = 1
     self.adviser.number_frames = 4
   end
-  if old < 70 then
-    self:addKeyHandler({"shift", "a"}, self, self.toggleAdviser)
-  end
   if old < 75 then
     self.current_momentum = { x = 0, y = 0 }
     self.momentum = self.app.config.scrolling_momentum
@@ -1133,17 +1197,20 @@ function GameUI:afterLoad(old, new)
   if old < 78 then
     self.current_momentum = { x = 0, y = 0, z = 0}
   end
-  if old < 81 then
-    self:removeKeyHandler("x", self, self.toggleWallsTransparent)
-    self:addKeyHandler("z", self, self.keySpeedUp)
-    self:addKeyHandler("x", self, self.keyTransparent)
-  end
   if old < 115 then
     self.shake_screen_intensity = 0
   end
   if old < 122 then
     self.multigesturemove = {x = 0.0, y = 0.0}
   end
+  if old < 129 then
+    self.recallpositions = {}
+  end
+  if old < 130 then
+    self.ticks_since_last_announcement = nil -- cleanup
+    self.announcer = Announcer(self.app)
+  end
+
   return UI.afterLoad(self, old, new)
 end
 
