@@ -148,7 +148,7 @@ function Room:dealtWithPatient(patient)
   patient = patient or self:getPatient()
   -- If the patient was sent home while in the room, don't
   -- do anything apart from removing any leading idle action.
-  if not patient.hospital then
+  if not patient.hospital or patient.going_home then
     if patient:getCurrentAction().name == "idle" then
       patient:finishAction()
     end
@@ -779,6 +779,7 @@ function Room:crashRoom()
       table.remove(self.world:getLocalPlayerHospital().emergency_patients, humanoid.is_emergency)
     end
     humanoid:die()
+    humanoid:despawn()
     self.world:destroyEntity(humanoid)
   end
 
@@ -786,6 +787,7 @@ function Room:crashRoom()
   for humanoid, _ in pairs(self.humanoids) do
     remove_humanoid(humanoid)
   end
+  self.humanoids = {}
   -- There might also be someone using the door, even if that person is just about to exit
   -- he/she is killed too.
   local walker = self.door.user
