@@ -56,6 +56,7 @@ function UI:initKeyAndButtonCodes()
     k = tostring(k):lower()
     return rawget(t, k) or k
   end})
+  --[===[
   do
     local ourpath = debug.getinfo(1, "S").source:sub(2, -7)
     local result, err = loadfile_envcall(ourpath .. "key_mapping.txt")
@@ -85,6 +86,7 @@ function UI:initKeyAndButtonCodes()
       result(env)
     end
   end
+  ]===]
 
   local keypad = {
     ["Keypad 0"] = "insert",
@@ -166,6 +168,11 @@ function UI:UI(app, minimal)
   }
   -- Windows can tell UI to pass specific codes forward to them. See addKeyHandler and removeKeyHandler
   self.key_handlers = {}
+  -- For use in onKeyUp when assigning hotkeys in the "Assign Hotkeys" window.
+  self.temp_button_down = false
+  --
+  self.key_noted = false
+  self.mouse_released = false
 
   self.down_count = 0
   if not minimal then
@@ -244,15 +251,14 @@ end
 
 function UI:setupGlobalKeyHandlers()
   -- Add some global keyhandlers
-  self:addKeyHandler("escape", self, self.closeWindow)
-  self:addKeyHandler("escape", self, self.stopMovie)
-  self:addKeyHandler("space", self, self.stopMovie)
-  self:addKeyHandler({"ctrl", "s"}, self, self.makeScreenshot)
-  self:addKeyHandler({"alt", "return"}, self, self.toggleFullscreen)
-  self:addKeyHandler({"alt", "keypad enter"}, self, self.toggleFullscreen)
-  self:addKeyHandler({"alt", "f4"}, self, self.exitApplication)
-  self:addKeyHandler({"shift", "f10"}, self, self.resetApp)
-  self:addKeyHandler({"ctrl", "f10"}, self, self.toggleCaptureMouse)
+  self:addKeyHandler("global_cancel", self, self.closeWindow)
+  self:addKeyHandler("global_cancel_alt", self, self.closeWindow)
+  self:addKeyHandler("global_stop_movie", self, self.stopMovie)
+  self:addKeyHandler("global_screenshot", self, self.makeScreenshot)
+  self:addKeyHandler("global_fullscreen_toggle", self, self.toggleFullscreen)
+  self:addKeyHandler("global_exitApp", self, self.exitApplication)
+  self:addKeyHandler("global_resetApp", self, self.resetApp)
+  self:addKeyHandler("global_releaseMouse", self, self.releaseMouse)
 
   self:addOrRemoveDebugModeKeyHandlers()
 end
@@ -272,7 +278,7 @@ function UI:playSound(name, played_callback, played_callback_delay)
 end
 
 -- Used for announcements only
-function UI:playAnnouncement(name, played_callback, played_callback_delay)
+function UI:playAnnouncement(name, priority, played_callback, played_callback_delay)
   if self.app.config.play_announcements then
     self.app.audio:playSound(name, nil, true, played_callback, played_callback_delay)
   end
@@ -303,7 +309,7 @@ function UI:setCursor(cursor)
     else
       -- Cursor is a Lua simulated cursor.
       -- Make the real cursor invisible, and simulate it with this.
-      WM.showCursor(false)
+      WM.showCursor(self.mouse_released)
       self.simulated_cursor = cursor
     end
   end
@@ -354,20 +360,100 @@ end
 -- pressed.
 --!param ... Additional arguments to `callback`.
 function UI:addKeyHandler(keys, window, callback, ...)
-  keys = (type(keys) == "table") and keys or {keys}
+  -- It is nessecary to clone the key table into another temporary table, as if we don't the original table that we take it from will lose
+  -- the last key of that table permenently in the next line of code after this one, until the program is restarted.
+  -- I.E. if the "ingame_quitLevel" hotkey from the "hotkeys_values" table in "config_finder.lua" is a table that looks like this:
+  --   {"shift", "q"}
+  -- We would lose the "q" element until we restarted the game and the "hotkey.txt" was read from again, causing the "ingame_quitLevel"
+  -- table to be reset back to {"shift, "q"}
+  local temp_keys = {}
 
-  local key = table.remove(keys, #keys):lower()
-  local modifiers = list_to_set(keys) -- SET of modifiers
-  if not self.key_handlers[key] then
-    -- No handlers for this key? Create a new table.
-    self.key_handlers[key] = {}
+  -- Check to see if "keys" key exist in the hotkeys table.
+  if self.app.hotkeys[keys] ~= nil then
+    if type(self.app.hotkeys[keys]) == "table" then
+      temp_keys = shallow_clone(self.app.hotkeys[keys])
+    elseif type(self.app.hotkeys[keys]) == "string" then
+      temp_keys = shallow_clone({self.app.hotkeys[keys]})
+    end
+  else
+    if type(keys) == "string" then
+      print(string.format("\"%s\" does not exist in the hotkeys configuration file.", keys))
+    else
+      print("Useage of addKeyHandler() requires the first argument to be a string of a key that can be found in the hotkeys configuration file.")
+    end
+  end
+
+  if temp_keys ~= nil then
+    local has_enterOrPlus
+    local temp_keys_copy = {}
+
+    if type(temp_keys) == "table" then
+      temp_keys_copy = shallow_clone(temp_keys)
+    elseif type(temp_keys) == "string" then
+      temp_keys_copy = {temp_keys}
+    end
+
+    for _, v in pairs(temp_keys_copy) do
+      if v == "enter" then
+        has_enterOrPlus = true
+      elseif v == "return" then
+        has_enterOrPlus = true
+      elseif v == "+" then
+        has_enterOrPlus = true
+      elseif v == "=" then
+        has_enterOrPlus = true
+      else
+        has_enterOrPlus = false
+      end
+    end
+
+    local key = table.remove(temp_keys, #temp_keys):lower()
+    local modifiers = list_to_set(temp_keys) -- SET of modifiers
+    if not self.key_handlers[key] then
+      -- No handlers for this key? Create a new table.
+      self.key_handlers[key] = {}
+    end
+
+    table.insert(self.key_handlers[key], {
+      modifiers = modifiers,
+      window = window,
+      callback = callback,
+      ...
+    })
+
+    -- If the handler added has enter, return, plus, or minus in it...
+    if has_enterOrPlus then
+      for k, _ in pairs(temp_keys_copy) do
+        if temp_keys_copy[k] == "enter" then
+          temp_keys_copy[k] = "return"
+        elseif temp_keys_copy[k] == "return" then
+          temp_keys_copy[k] = "enter"
+        elseif temp_keys_copy[k] == "+" then
+          temp_keys_copy[k] = "="
+        elseif temp_keys_copy[k] == "=" then
+          temp_keys_copy[k] = "+"
+        end
+      end
+
+      local key_02 = table.remove(temp_keys_copy, #temp_keys_copy):lower()
+      local modifiers_02 = list_to_set(temp_keys_copy) -- SET of modifiers
+      if not self.key_handlers[key_02] then
+        -- No handlers for this key? Create a new table.
+        self.key_handlers[key_02] = {}
+      end
+
+      -- Then make the same handler, but with the complementary button.
+      --  i.e. If it asks for "enter", it will also add "return".
+      table.insert(self.key_handlers[key_02], {
+        modifiers = modifiers_02,
+        window = window,
+        callback = callback,
+        ...
+      })
+    end
+  else
+    print("addKeyHandler() failed.")
   end
-  table.insert(self.key_handlers[key], {
-    modifiers = modifiers,
-    window = window,
-    callback = callback,
-    ...
-  })
 end
 
 --! Unregister a key handler previously registered by `addKeyHandler`.
@@ -376,32 +462,120 @@ end
 --!param window (Window) The window of a key / window pair previously passed
 -- to `addKeyHandler`.
 function UI:removeKeyHandler(keys, window)
-  keys = (type(keys) == "table") and keys or {keys}
+  local temp_keys = nil
 
-  local key = table.remove(keys, #keys):lower()
-  local modifiers = list_to_set(keys) -- SET of modifiers
-  if self.key_handlers[key] then
-    for index, info in ipairs(self.key_handlers[key]) do
-      if info.window == window and compare_tables(info.modifiers, modifiers) then
-        table.remove(self.key_handlers[key], index)
+  -- Check to see if "keys" key exist in the hotkeys table.
+  if self.app.hotkeys[keys] ~= nil then
+    if type(self.app.hotkeys[keys]) == "table" then
+      temp_keys = shallow_clone(self.app.hotkeys[keys])
+    elseif type(self.app.hotkeys[keys]) == "string" then
+      temp_keys = shallow_clone({self.app.hotkeys[keys]})
+    end
+  else
+    if type(keys) == "string" then
+      print(string.format("\"%s\" does not exist in the \"ui.key_handlers\" table.", keys))
+    else
+      print("Useage of removeKeyHandler() requires the first argument to be a string of a key that can be found in the \"ui.key_handlers\" table.")
+    end
+  end
+
+  if temp_keys ~= nil then
+    local has_enterOrPlus
+    local temp_keys_copy = {}
+
+    if type(temp_keys) == "table" then
+      temp_keys_copy = shallow_clone(temp_keys)
+    elseif type(temp_keys) == "string" then
+      temp_keys_copy = shallow_clone({temp_keys})
+    end
+
+    for _, v in pairs(temp_keys_copy) do
+      if v == "enter" then
+        has_enterOrPlus = true
+      elseif v == "return" then
+        has_enterOrPlus = true
+      elseif v == "+" then
+        has_enterOrPlus = true
+      elseif v == "=" then
+        has_enterOrPlus = true
+      else
+        has_enterOrPlus = false
       end
     end
-    -- If last key handler was removed, delete the (now empty) list.
-    if #self.key_handlers[key] == 0 then
-      self.key_handlers[key] = nil
+
+    local key = table.remove(temp_keys, #temp_keys):lower()
+    local modifiers = list_to_set(temp_keys) -- SET of modifiers
+    if self.key_handlers[key] then
+      for index, info in ipairs(self.key_handlers[key]) do
+        if info.window == window and compare_tables(info.modifiers, modifiers) then
+          table.remove(self.key_handlers[key], index)
+        end
+      end
+      -- If last key handler was removed, delete the (now empty) list.
+      if #self.key_handlers[key] == 0 then
+        self.key_handlers[key] = nil
+      end
+    end
+
+    -- If the handler added has enter, return, plus, or minus in it...
+    if has_enterOrPlus then
+      for k, _ in pairs(temp_keys_copy) do
+        if temp_keys_copy[k] == "enter" then
+          temp_keys_copy[k] = "return"
+        elseif temp_keys_copy[k] == "return" then
+          temp_keys_copy[k] = "enter"
+        elseif temp_keys_copy[k] == "+" then
+          temp_keys_copy[k] = "="
+        elseif temp_keys_copy[k] == "=" then
+          temp_keys_copy[k] = "+"
+        end
+      end
+
+      local key_02 = table.remove(temp_keys_copy, #temp_keys_copy):lower()
+      local modifiers_02 = list_to_set(temp_keys_copy) -- SET of modifiers
+      if self.key_handlers[key_02] then
+        for index, info in ipairs(self.key_handlers[key_02]) do
+          if info.window == window and compare_tables(info.modifiers, modifiers_02) then
+            table.remove(self.key_handlers[key_02], index)
+          end
+        end
+        -- If last key handler was removed, delete the (now empty) list.
+        if #self.key_handlers[key_02] == 0 then
+          self.key_handlers[key_02] = nil
+        end
+      end
     end
   end
 end
 
-local menu_bg_sizes = { -- Available menu background sizes
-  {1920, 1080},
-}
-
+--! Set the menu background image
+--!
+--! The menu size closest to, but no larger than the height of the currently
+--! set game window is selected. If no image fits that criteria the smallest
+--! available image is used.
 function UI:setMenuBackground()
-  local bg_size = menu_bg_sizes[1]
-  self.background = self.app.gfx:loadRaw("mainmenu" .. bg_size[2], bg_size[1], bg_size[2], "Bitmap")
+  local screen_h = self.app.config.height
+  local bg_size_idx = 1
+
+  -- Available mainmenu*.bmp sizes
+  local menu_bg_sizes = {
+    {640, 480},
+    {1280, 720},
+    {1920, 1080},
+  }
+
+  for i, bg_size in ipairs(menu_bg_sizes) do
+    if screen_h >= bg_size[2] then
+      bg_size_idx = i
+    else
+      break
+    end
+  end
+
+  local bg_size = menu_bg_sizes[bg_size_idx]
   self.background_width = bg_size[1]
   self.background_height = bg_size[2]
+  self.background = self.app.gfx:loadRaw("mainmenu" .. bg_size[2], bg_size[1], bg_size[2], "Bitmap")
 end
 
 function UI:onChangeResolution()
@@ -431,6 +605,19 @@ function UI:unregisterTextBox(box)
   end
 end
 
+function UI:registerHotkeyBox(box)
+  self.hotkeyboxes[#self.hotkeyboxes + 1] = box
+end
+
+function UI:unregisterHotkeyBox(box)
+  for num, b in ipairs(self.hotkeyboxes) do
+    if b == box then
+      table.remove(self.hotkeyboxes, num)
+      break
+    end
+  end
+end
+
 function UI:changeResolution(width, height)
   self.app:prepareVideoUpdate()
   local error_message = self.app.video:update(width, height, unpack(self.app.modes))
@@ -463,6 +650,26 @@ function UI:toggleCaptureMouse()
   self.app.video:setCaptureMouse(self.app.capturemouse)
 end
 
+function UI:setMouseReleased(released)
+  if released == self.mouse_released then
+    return
+  end
+
+  self.mouse_released = released
+
+  -- If we are using a software cursor, show the hardware cursor on release
+  -- and hide it again on capture.
+  if self.cursor and not self.cursor.use then
+    WM.showCursor(released)
+  end
+
+  self.app.video:setCaptureMouse(self.app.capturemouse and not self.app.mouse_released)
+end
+
+function UI:releaseMouse()
+  self:setMouseReleased(true)
+end
+
 function UI:toggleFullscreen()
   local modes = self.app.modes
 
@@ -535,7 +742,6 @@ function UI:onKeyDown(rawchar, modifiers, is_repeat)
 
   -- Remove numlock modifier
   modifiers["numlockactive"] = nil
-
   -- If there is one, the current textbox gets the key.
   -- It will not process any text at this point though.
   for _, box in ipairs(self.textboxes) do
@@ -544,6 +750,13 @@ function UI:onKeyDown(rawchar, modifiers, is_repeat)
     end
   end
 
+  -- If there is a hotkey box
+  for _, hotkeybox in ipairs(self.hotkeyboxes) do
+    if hotkeybox.enabled and hotkeybox.active and not handled then
+      handled = hotkeybox:keyInput(key, rawchar, modifiers)
+    end
+  end
+
   -- Otherwise, if there is a key handler bound to the given key, then it gets
   -- the key.
   if not handled then
@@ -573,15 +786,49 @@ function UI:onKeyUp(rawchar)
             string.sub(rawchar,1,6) == "Keypad" and string.sub(rawchar,8) or
             rawchar
   local key = rawchar:lower()
-  do
-    local mapped_button = self.key_to_button_remaps[key]
-    if mapped_button then
-      self:onMouseUp(mapped_button, self.cursor_x, self.cursor_y)
-      return true
-    end
-    key = self.key_remaps[key] or key
-  end
+
   self.buttons_down[key] = nil
+
+  -- Go through all the hotkeyboxes.
+  for _, hotkeybox in ipairs(self.hotkeyboxes) do
+    -- If one is enabled and active...
+    if hotkeybox.enabled and hotkeybox.active then
+      -- If the key lifted is escape...
+      if(key == "escape") then
+        hotkeybox:abort()
+        hotkeybox.noted_keys = {}
+      else
+        -- Check if the current key lifted has already been noted.
+        self.key_noted = false
+        for _, v in pairs(hotkeybox.noted_keys) do
+          if v == key then
+            self.key_noted = true
+          end
+        end
+
+        -- If the current key hasn't been noted...
+        if self.key_noted == false then
+          hotkeybox.noted_keys[#hotkeybox.noted_keys + 1] = key
+        end
+
+        -- Says if there is still a button being pressed.
+        self.temp_button_down = false
+
+        -- Go through and check if there are still any buttons pressed. If so...
+        for _, _ in pairs(self.buttons_down) do
+          -- Then toggle the corresponding bool.
+          self.temp_button_down = true
+        end
+
+        --If there ISN'T still a button down when a button was released...
+        if self.temp_button_down == false then
+          -- Activate the confirm function on the hotkey box.
+          hotkeybox:confirm()
+          hotkeybox.noted_keys = {}
+        end
+      end
+    end
+  end
 end
 
 function UI:onEditingText(text, start, length)
@@ -616,6 +863,7 @@ function UI:onTextInput(text)
 end
 
 function UI:onMouseDown(code, x, y)
+  self:setMouseReleased(false)
   local repaint = false
   local button = self.button_codes[code] or code
   if self.app.moviePlayer.playing then
@@ -725,6 +973,10 @@ function UI:onWindowResize(width, height)
 end
 
 function UI:onMouseMove(x, y, dx, dy)
+  if self.mouse_released then
+    return false
+  end
+
   local repaint = UpdateCursorPosition(self.app.video, x, y)
 
   self.cursor_x = x
@@ -744,6 +996,13 @@ function UI:onMouseMove(x, y, dx, dy)
   return repaint
 end
 
+--! Process SDL_MULTIGESTURE events.
+--!
+--!return (boolean) event processed indicator
+function UI:onMultiGesture()
+  return false
+end
+
 function UI:onTick()
   Window.onTick(self)
   local repaint = false
@@ -804,56 +1063,23 @@ function UI:getCursorPosition(window)
 end
 
 function UI:addOrRemoveDebugModeKeyHandlers()
-  self:removeKeyHandler({"ctrl", "c"}, self)
-  self:removeKeyHandler("f12", self)
-  self:removeKeyHandler({"shift", "d"}, self)
+  self:removeKeyHandler("global_connectDebugger", self)
+  self:removeKeyHandler("global_showLuaConsole", self)
+  self:removeKeyHandler("global_runDebugScript", self)
   if self.app.config.debug then
-    self:addKeyHandler({"ctrl", "c"}, self, self.connectDebugger)
-    self:addKeyHandler("f12", self, self.showLuaConsole)
-    self:addKeyHandler({"shift", "d"}, self, self.runDebugScript)
+    self:addKeyHandler("global_connectDebugger", self, self.connectDebugger)
+    self:addKeyHandler("global_showLuaConsole", self, self.showLuaConsole)
+    self:addKeyHandler("global_runDebugScript", self, self.runDebugScript)
   end
 end
 
 function UI:afterLoad(old, new)
+  -- Get rid of old key handlers from save file.
+  self.key_handlers = {}
   if old < 5 then
     self.editing_allowed = true
   end
-  if old < 63 then
-    -- modifiers have been added to key handlers
-    for _, handlers in pairs(self.key_handlers) do
-      for _, handler in ipairs(handlers) do
-        handler.modifiers = {}
-      end
-    end
-    -- some global key shortcuts were converted to use keyHandlers
-    self:removeKeyHandler("f12", self)
-    self:removeKeyHandler({"shift", "d"}, self)
-    self:setupGlobalKeyHandlers()
-  end
-
-  if old < 70 then
-    self:removeKeyHandler("f10", self)
-    self:addKeyHandler({"shift", "f10"}, self, self.resetApp)
-    self:removeKeyHandler("a", self)
-  end
-  -- changing this so that it is quit application and Shift + Q is quit to main menu
-  if old < 71 then
-    self:removeKeyHandler({"alt", "f4"}, self, self.quit)
-    self:addKeyHandler({"alt", "f4"}, self, self.exitApplication)
-  end
-
-  if old < 100 then
-    self:removeKeyHandler({"alt", "enter"}, self)
-    self:addKeyHandler({"alt", "return"}, self, self.toggleFullscreen)
-  end
-  if old < 104 then
-    self:addKeyHandler({"alt", "keypad enter"}, self, self.toggleFullscreen)
-  end
-
-  if old < 118 then
-    self:addKeyHandler({"ctrl", "f10"}, self, self.toggleCaptureMouse)
-  end
-
+  self:setupGlobalKeyHandlers()
   Window.afterLoad(self, old, new)
 end
 
