@@ -1,4 +1,4 @@
-static const uint16_t g_aCP437toUnicode[0x80] = {
+static const uint16_t cp437_to_unicode_table[0x80] = {
     /* 0x00 through 0x7F need no translation */
     0x00C7, 0x00FC, 0x00E9, 0x00E2, 0x00E4, 0x00E0, 0x00E5, 0x00E7,
     0x00EA, 0x00EB, 0x00E8, 0x00EF, 0x00EE, 0x00EC, 0x00C4, 0x00C5,
