@@ -63,15 +63,15 @@ extern "C"
 #endif
 
 
-//! \brief A picture in THMoviePictureBuffer
+//! \brief A picture in movie_picture_buffer
 //!
 //! Stores the picture from a frame in the movie from the time that it is
 //! processed until it should be drawn.
-class THMoviePicture
+class movie_picture
 {
 public:
-    THMoviePicture();
-    ~THMoviePicture();
+    movie_picture();
+    ~movie_picture();
 
     //! Allocate the buffer to hold a picture of the given size
     void allocate(int iWidth, int iHeight);
@@ -79,20 +79,20 @@ public:
     //! Delete the buffer
     void deallocate();
 
-    uint8_t* m_pBuffer; ///< Pixel data in #m_pixelFormat
-    const AVPixelFormat m_pixelFormat; ///< The format of pixels to output
-    int m_iWidth; ///< Picture width
-    int m_iHeight; ///< Picture height
-    double m_dPts; ///< Presentation time stamp
-    std::mutex m_mutex; ///< Mutex protecting this picture
+    uint8_t* buffer; ///< Pixel data in #m_pixelFormat
+    const AVPixelFormat pixel_format; ///< The format of pixels to output
+    int width; ///< Picture width
+    int height; ///< Picture height
+    double pts; ///< Presentation time stamp
+    std::mutex mutex; ///< Mutex protecting this picture
 };
 
 //! A buffer for holding movie pictures and drawing them to the renderer
-class THMoviePictureBuffer
+class movie_picture_buffer
 {
 public:
-    THMoviePictureBuffer();
-    ~THMoviePictureBuffer();
+    movie_picture_buffer();
+    ~movie_picture_buffer();
 
     //NB: The following functions are called by the main program thread
 
@@ -103,14 +103,14 @@ public:
     void reset();
 
     //! Ready the picture buffer for a new renderer or new picture dimensions
-    //! by allocating each THMoviePicture in the queue, resetting the read
+    //! by allocating each movie_picture in the queue, resetting the read
     //! index and allocating a new texture.
     //!
     //! \remark Must be run on the program's graphics thread
     void allocate(SDL_Renderer *pRenderer, int iWidth, int iHeight);
 
     //! Destroy the associated texture and deallocate each of the
-    //! THMoviePictures in the queue so that the program can release
+    //! movie_pictures in the queue so that the program can release
     //! the renderer
     //!
     //! \remark Must be run on the program's graphics thread
@@ -119,7 +119,7 @@ public:
     //! Advance the read index
     bool advance();
 
-    //! Draw the THMoviePicture at the current read index
+    //! Draw the movie_picture at the current read index
     //!
     //! \param pRenderer The renderer to draw the picture to
     //! \param dstrect The rectangle on the renderer to draw to
@@ -128,11 +128,11 @@ public:
     void draw(SDL_Renderer *pRenderer, const SDL_Rect &dstrect);
 
     //! Get the next presentation time stamp
-    double getNextPts();
+    double get_next_pts();
 
     //! Return whether there are any pictures left to draw in the picture queue
     //!
-    //! \remark If the THPictureBuffer is not allocated it cannot be read from
+    //! \remark If the movie_picture_buffer is not allocated it cannot be read from
     //! or written to. Consequently it is both full and empty.
     bool empty();
 
@@ -140,7 +140,7 @@ public:
 
     //! Return whether there is space to add any more frame data to the queue
     //!
-    //! \remark If the THPictureBuffer is not allocated it cannot be read from
+    //! \remark If the movie_picture_buffer is not allocated it cannot be read from
     //! or written to. Consequently it is both full and empty.
     bool full();
 
@@ -155,33 +155,33 @@ private:
     //! Return whether there is space to add any more frame data to the queue
     //!
     //! \remark Requires external locking
-    bool unsafeFull();
+    bool unsafe_full();
 
-    static const size_t ms_pictureBufferSize = 4; ///< The number of elements to allocate in the picture queue
-    std::atomic<bool> m_aborting; ///< Whether we are in the process of aborting
-    bool m_fAllocated; ///< Whether the picture buffer has been allocated (and hasn't since been deallocated)
-    int m_iCount; ///< The number of elements currently written to the picture queue
-    int m_iReadIndex; ///< The position in the picture queue to be read next
-    int m_iWriteIndex; ///< The position in the picture queue to be written to next
-    SwsContext* m_pSwsContext; ///< The context for software scaling and pixel conversion when writing to the picture queue
-    SDL_Texture *m_pTexture; ///< The (potentially hardware) texture to draw the picture to. In OpenGL this should only be accessed on the main thread
-    std::mutex m_mutex; ///< A mutex for restricting access to the picture buffer to a single thread
-    std::condition_variable m_cond; ///< A condition for indicating access to the picture buffer
-    THMoviePicture m_aPictureQueue[ms_pictureBufferSize]; ///< The picture queue, a looping FIFO queue of THMoviePictures
+    static const size_t picture_buffer_size = 4; ///< The number of elements to allocate in the picture queue
+    std::atomic<bool> aborting; ///< Whether we are in the process of aborting
+    bool allocated; ///< Whether the picture buffer has been allocated (and hasn't since been deallocated)
+    int picture_count; ///< The number of elements currently written to the picture queue
+    int read_index; ///< The position in the picture queue to be read next
+    int write_index; ///< The position in the picture queue to be written to next
+    SwsContext* sws_context; ///< The context for software scaling and pixel conversion when writing to the picture queue
+    SDL_Texture *texture; ///< The (potentially hardware) texture to draw the picture to. In OpenGL this should only be accessed on the main thread
+    std::mutex mutex; ///< A mutex for restricting access to the picture buffer to a single thread
+    std::condition_variable cond; ///< A condition for indicating access to the picture buffer
+    movie_picture picture_queue[picture_buffer_size]; ///< The picture queue, a looping FIFO queue of movie_pictures
 };
 
 //! The AVPacketQueue is a thread safe queue of movie packets
-class THAVPacketQueue
+class av_packet_queue
 {
 public:
     //! Construct a new empty packet queue
-    THAVPacketQueue();
+    av_packet_queue();
 
     //! Destroy the packet queue.
     //!
     //! \remarks Does not free the included packets. The packet queue should be
     //! flushed before it is destroyed.
-    ~THAVPacketQueue();
+    ~av_packet_queue();
 
     //! Push a new packet on the back of the queue
     void push(AVPacket *packet);
@@ -193,39 +193,39 @@ public:
     AVPacket* pull(bool block);
 
     //! Return the number of packets in the queue
-    int getCount() const;
+    int get_count() const;
 
     //! Release a blocking pull without writing a new packet to the queue.
     void release();
 private:
-    AVPacketList *m_pFirstPacket; ///< The packet at the front of the queue
-    AVPacketList *m_pLastPacket; ///< The packet at the end of the queue
-    int iCount; ///< The number of packets in the queue
-    std::mutex m_mutex; ///< A mutex restricting access to the packet queue to a single thread
-    std::condition_variable m_cond; ///< A condition to wait on for signaling the packet queue
+    AVPacketList *first_packet; ///< The packet at the front of the queue
+    AVPacketList *last_packet; ///< The packet at the end of the queue
+    int count; ///< The number of packets in the queue
+    std::mutex mutex; ///< A mutex restricting access to the packet queue to a single thread
+    std::condition_variable cond; ///< A condition to wait on for signaling the packet queue
 };
 #endif //CORSIX_TH_USE_FFMPEG || CORSIX_TH_USE_LIBAV
 
 //! Movie player for CorsixTH
 //!
 //! The movie player is designed to be preinitialized and used for multiple
-//! movies. After initializing the movie player, call THMovie::setRenderer
-//! to assign the current SDL renderer to the movie player. Then THMovie::load
-//! the desired movie and finally THMovie::play it.
-class THMovie
+//! movies. After initializing the movie player, call movie_player::set_renderer
+//! to assign the current SDL renderer to the movie player. Then movie_player::load
+//! the desired movie and finally movie_player::play it.
+class movie_player
 {
 public:
-    //! Construct a new THMovie
-    THMovie();
+    //! Construct a new movie_player
+    movie_player();
 
-    //! Destroy the THMovie
-    ~THMovie();
+    //! Destroy the movie_player
+    ~movie_player();
 
     //! Assign the renderer on which to draw the movie
-    void setRenderer(SDL_Renderer *pRenderer);
+    void set_renderer(SDL_Renderer *pRenderer);
 
     //! Return whether movies were compiled into CorsixTH
-    bool moviesEnabled() const;
+    bool movies_enabled() const;
 
     //! Load the movie with the given file name
     bool load(const char* szFilepath);
@@ -245,20 +245,20 @@ public:
     void stop();
 
     //! Return the original height of the movie
-    int getNativeHeight() const;
+    int get_native_height() const;
 
     //! Return the original width of the movie
-    int getNativeWidth() const;
+    int get_native_width() const;
 
     //! Return whether the movie has an audio stream
-    bool hasAudioTrack() const;
+    bool has_audio_track() const;
 
     //! Return a text description of the last error encountered
-    const char* getLastError() const;
+    const char* get_last_error() const;
 
     //! Clear the last error so that if there is no more errors before the next
-    //! call to THMovie::getLastError() it will return an empty string.
-    void clearLastError();
+    //! call to movie_player::get_last_error() it will return an empty string.
+    void clear_last_error();
 
     //! Draw the next frame if it is time to do so
     //!
@@ -271,48 +271,48 @@ public:
     //! \remark This destroys the textures and other resources that may lock
     //! the renderer from being deleted. If the target changes you would call
     //! this, then free and switch renderers in the outside program, then call
-    //! THMovie::setRenderer and finally THMovie::allocatePictureBuffer.
+    //! movie_player::set_renderer and finally movie_player::allocate_picture_buffer.
     //! \remark Up to the size of the picture buffer frames may be lost during
     //! this process.
-    void deallocatePictureBuffer();
+    void deallocate_picture_buffer();
 
     //! Allocate the picture buffer for the current renderer
-    void allocatePictureBuffer();
+    void allocate_picture_buffer();
 
     //! Read packets from the movie and allocate them to the appropriate stream
     //! packet queues. Signal if we have reached the end of the movie.
     //!
     //! \remark This should not be called externally. It is public as it is the
     //! entry point of a thread.
-    void readStreams();
+    void read_streams();
 
     //! Read video frames from the video packet queue and write them to the
     //! picture queue.
     //!
     //! \remark This should not be called externally. It is public as it is the
     //! entry point of a thread.
-    void runVideo();
+    void run_video();
 
     //! Read audio from the audio packet queue, and copy it into the audio
     //! buffer for playback
-    void copyAudioToStream(uint8_t *pbStream, int iStreamSize);
+    void copy_audio_to_stream(uint8_t *pbStream, int iStreamSize);
 
 private:
 #if (defined(CORSIX_TH_USE_FFMPEG) || defined(CORSIX_TH_USE_LIBAV)) && defined(CORSIX_TH_USE_SDL_MIXER)
-    static const size_t ms_movieErrorBufferSize = 128; ///< Buffer to hold last error description
-    static const size_t ms_audioBufferSize = 1024; ///< Buffer for audio playback
+    static const size_t movie_error_buffer_capacity = 128; ///< Buffer to hold last error description
+    static const size_t audio_chunk_buffer_capacity = 1024; ///< Buffer for audio playback
 
     //! Get the AVCodecContext associated with a given stream
-    AVCodecContext* getCodecContextForStream(AVCodec* codec, AVStream* stream) const;
+    AVCodecContext* get_codec_context_for_stream(AVCodec* codec, AVStream* stream) const;
 
     //! Get the time the given frame should be played (from the start of the stream)
     //!
     //! \param frame The video or audio frame
     //! \param streamIndex The position of the stream in m_pFormatContexts streams array
-    double getPresentationTimeForFrame(AVFrame* frame, int streamIndex) const;
+    double get_presentation_time_for_frame(AVFrame* frame, int streamIndex) const;
 
     //! Decode audio from the movie into a format suitable for playback
-    int decodeAudioFrame(bool fFirst);
+    int decode_audio_frame(bool fFirst);
 
 #ifdef CORSIX_TH_MOVIE_USE_SEND_PACKET_API
     //! Convert packet data into frames
@@ -321,70 +321,71 @@ private:
     //! \param pFrame An empty frame which gets populated by the data in the
     //! packet queue.
     //! \returns FFMPEG result of avcodec_recieve_frame
-    int getFrame(int stream, AVFrame* pFrame);
+    int get_frame(int stream, AVFrame* pFrame);
 #else
     //! Convert video packet data into a frame.
     //!
     //! \param pFrame An empty frame which gets populated by the data in the
     //! video packet queue.
     //! \returns 1 if the frame was received, 0 if it was not, and < 0 on error
-    int getVideoFrame(AVFrame *pFrame);
+    int get_video_frame(AVFrame *pFrame);
 #endif
 
-    SDL_Renderer *m_pRenderer; ///< The renderer to draw to
+    SDL_Renderer *renderer; ///< The renderer to draw to
 
     //! A description of the last error
-    std::string m_sLastError;
+    std::string last_error;
 
     //! A buffer for passing to ffmpeg to get error details
-    char m_szErrorBuffer[ms_movieErrorBufferSize];
+    char error_buffer[movie_error_buffer_capacity];
 
-    bool m_fAborting; ///< Indicate that we are in process of aborting playback
+    // TODO: Should be atomic
+    bool aborting; ///< Indicate that we are in process of aborting playback
 
-    std::mutex m_decodingAudioMutex; ///< Synchronize access to #m_pAudioBuffer
+    std::mutex decoding_audio_mutex; ///< Synchronize access to #m_pAudioBuffer
 
-    AVFormatContext* m_pFormatContext; ///< Information related to the loaded movie and all of its streams
-    int m_iVideoStream; ///< The index of the video stream
-    int m_iAudioStream; ///< The index of the audio stream
-    AVCodecContext* m_pVideoCodecContext; ///< The video codec and information related to video
-    AVCodecContext* m_pAudioCodecContext; ///< The audio codec and information related to audio
+    AVFormatContext* format_context; ///< Information related to the loaded movie and all of its streams
+    int video_stream_index; ///< The index of the video stream
+    int audio_stream_index; ///< The index of the audio stream
+    AVCodecContext *video_codec_context; ///< The video codec and information related to video
+    AVCodecContext *audio_codec_context; ///< The audio codec and information related to audio
 
     //queues for transferring data between threads
-    THAVPacketQueue *m_pVideoQueue; ///< Packets from the video stream
-    THAVPacketQueue *m_pAudioQueue; ///< Packets from the audio stream
-    THMoviePictureBuffer *m_pMoviePictureBuffer; ///< Buffer of processed video
+    av_packet_queue *video_queue; ///< Packets from the video stream
+    av_packet_queue *audio_queue; ///< Packets from the audio stream
+    ::movie_picture_buffer *movie_picture_buffer; ///< Buffer of processed video
 
     //clock sync parameters
-    int m_iCurSyncPtsSystemTime; ///< System time matching #m_iCurSyncPts
-    double m_iCurSyncPts; ///< The current presentation time stamp (from the audio stream)
+    int current_sync_pts_system_time; ///< System time matching #m_iCurSyncPts
+    double current_sync_pts; ///< The current presentation time stamp (from the audio stream)
 
 #ifdef CORSIX_TH_USE_FFMPEG
-    SwrContext* m_pAudioResampleContext; ///< Context for resampling audio for playback with ffmpeg
+    SwrContext* audio_resample_context; ///< Context for resampling audio for playback with ffmpeg
 #elif defined(CORSIX_TH_USE_LIBAV)
-    AVAudioResampleContext* m_pAudioResampleContext; ///< Context for resampling audio for playback with libav
+    AVAudioResampleContext* audio_resample_context; ///< Context for resampling audio for playback with libav
 #endif
 
-    int m_iAudioBufferSize; ///< The current size of audio data in #m_pbAudioBuffer
-    int m_iAudioBufferIndex; ///< The current position for writing in #m_pbAudioBuffer
-    int m_iAudioBufferMaxSize; ///< The capacity of #m_pbAudioBuffer (allocated size)
-    uint8_t* m_pbAudioBuffer; ///< An audio buffer for playback
+    int audio_buffer_size; ///< The current size of audio data in #m_pbAudioBuffer
+    int audio_buffer_index; ///< The current position for writing in #m_pbAudioBuffer
+    int audio_buffer_max_size; ///< The capacity of #m_pbAudioBuffer (allocated size)
+    uint8_t* audio_buffer; ///< An audio buffer for playback
 
-    AVPacket* m_pAudioPacket; ///< The current audio packet being decoded (audio frames don't necessarily line up with packets)
-    int m_iAudioPacketSize; ///< The size of #m_pbAudioPacketData
-    uint8_t *m_pbAudioPacketData; ///< Original data for #m_pAudioPacket, kept so that it can be freed after the packet is processed
-    AVFrame* m_audio_frame; ///< The frame we are decoding audio into
+    AVPacket* audio_packet; ///< The current audio packet being decoded (audio frames don't necessarily line up with packets)
+    int audio_packet_size; ///< The size of #m_pbAudioPacketData
+    uint8_t *audio_packet_data; ///< Original data for #m_pAudioPacket, kept so that it can be freed after the packet is processed
+    AVFrame* audio_frame; ///< The frame we are decoding audio into
 
-    Mix_Chunk* m_pChunk; ///< Empty chunk needed for SDL_mixer
-    uint8_t* m_pbChunkBuffer; ///< 0'd out buffer for the SDL_Mixer chunk
+    Mix_Chunk* empty_audio_chunk; ///< Empty chunk needed for SDL_mixer
+    uint8_t* audio_chunk_buffer; ///< 0'd out buffer for the SDL_Mixer chunk
 
-    int m_iChannel; ///< The channel to play audio on, -1 for none
-    int m_iMixerChannels; ///< How many channels to play on (1 - mono, 2 - stereo)
-    int m_iMixerFrequency; ///< The frequency of audio expected by SDL_Mixer
+    int audio_channel; ///< The channel to play audio on, -1 for none
+    int mixer_channels; ///< How many channels to play on (1 - mono, 2 - stereo)
+    int mixer_frequency; ///< The frequency of audio expected by SDL_Mixer
 
-    AVPacket* m_flushPacket; ///< A representative packet indicating a flush is required.
+    AVPacket* flush_packet; ///< A representative packet indicating a flush is required.
 
-    std::thread m_streamThread; ///< The thread responsible for reading the movie streams
-    std::thread m_videoThread; ///< The thread responsible for decoding the video stream
+    std::thread stream_thread; ///< The thread responsible for reading the movie streams
+    std::thread video_thread; ///< The thread responsible for decoding the video stream
 #endif //CORSIX_TH_USE_FFMPEG || CORSIX_TH_USE_LIBAV
 };
 
